@@ -4,12 +4,12 @@ Created on Fri Jan 13 18:46:11 2023
 
 @author: Administrator
 """
-import os,platform
+import os,platform,winshell,file
 def sudopy(*shell,password='',timeout=1800000):
     if platform.system()=='Windows':
         with open("temp.py",'a') as f:
             f.write(shell)
-        os.system('sudo py temp.py')
+        winshell.powershell(r"sudo.ps1", r"py temp.py")
     elif platform.system()=='Linux':
         with open("temp.py",'a') as f:
             f.write(shell)
@@ -17,9 +17,11 @@ def sudopy(*shell,password='',timeout=1800000):
             os.system('sudo python temp.py')
         else:
             os.system('sudo -S '+password+' python temp.py')
+    file.rmfile(r"temp.py")
+    
 def sudo(shell,password='',timeout=1800000):
     if platform.system()=='Windows':
-        os.system('sudo '+shell)
+        winshell.powershell(r"sudo.ps1", shell)
     elif platform.system()=='Linux':
         if not password:
             os.system('sudo python temp.py')
